OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "{circle} ezabatu duzu",
    "{author} deleted {circle}" : "{author}(e)k {circle} ezabatu du",
    "You joined {circle}" : "{circle} zirkuluan sartu zara",
    "{member} joined {circle}" : "{member} kidea {circle} zirkuluan sartu da",
    "You accepted the invitation to join {circle}" : "{circle} zirkuluan sartzeko gonbidapena onartu duzu",
    "{member} accepted the invitation to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera onartu du",
    "You added {member} as member to {circle}" : "{member} gehitu duzu kide gisa {circle} zirkulura",
    "You have been added as member to {circle} by {author}" : "{circle} zirkulura gehitu zaitu {author}(e)k",
    "{member} has been added as member to {circle} by {author}" : "{member} kide gisa gehitu du {circle} zirkulura {author}(e)k",
    "You added {external} to {circle}" : "{external} gehitu duzu {circle}  zirkulura",
    "{external} has been added to {circle} by {author}" : "{external} gehitu du {circle} zirkulura {author}(e)k",
    "You accepted {member}'s request to join {circle}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera onartu duzu",
    "Your request to join {circle} has been accepted by {author}" : "{circle} zirkuluan sartzeko zure eskaera onartu du {author}(e)k ",
    "{member}'s request to join {circle} has been accepted by {author}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera onartu du {author}(e)k",
    "You left {circle}" : "{circle} zirkulutik atera zara",
    "{member} left {circle}" : "{member} kidea {circle} zirkulutik atera da",
    "You declined the invitation to join {circle}" : " {circle} zirkuluan sartzeko gonbidapenari uko egin diozu",
    "{member} declined an invitation to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko gonbidapenari uko egin dio",
    "You cancelled your request to join {circle}" : "{circle} zirkuluan sartzeko eskaera bertan behera utzi duzu",
    "You removed {member} from {circle}" : "{member} kidea atera duzu {circle} zirkulutik",
    "You have been removed from {circle} by {author}" : "{circle} zirkulutik atera zaitu {author}(e)k",
    "{member} has been removed from {circle} by {author}" : "{member} kidea atera du {circle} zirkulutik {author}(e)k",
    "You removed {external} from {circle}" : "{external} atera duzu {circle} zirkulutik",
    "{external} has been removed from {circle} by {author}" : "{external} atera du {circle} zirkulutik {author}(e)k",
    "You cancelled {member}'s invitation to join {circle}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera baztertu duzu",
    "Your invitation to join {circle} has been cancelled by {author}" : "{circle} zirkuluan sartzeko zure eskaera baztertu egin du {author}(e)k",
    "{author} cancelled {member}'s invitation to join {circle}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera baztertu du {author}(e)k",
    "You dismissed {member}'s request to join {circle}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera baztertu duzu",
    "Your request to join {circle} has been dismissed by {author}" : "{circle} zirkuluan sartzeko zure eskaera baztertu egin du {author}(e)k ",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{circle} zirkuluan sartzeko {member} kidearen eskaera baztertu du {author}(e)k",
    "You invited {member} to join {circle}" : "{member} kidea {circle} zirkulura gonbidatu duzu",
    "You have been invited to join {circle} by {author}" : "{circle} zirkulura gonbidatu zaitu {author}(e)k",
    "{member} has been invited to join {circle} by {author}" : "{member} kidea gonbidatu du {circle} zirkulura {author}(e)k",
    "You changed {member}'s level in {circle} to %1$s" : "{circle} zirkuluan {member} kidearen maila aldatu duzu %1$s-ra",
    "{author} changed your level in {circle} to %1$s" : "{author}(e)k {circle} zirkuluan zure maila aldatu du %1$s-ra",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author}(e)k {circle} zirkuluan [member] kidearen maila aldatu du %1$s-ra",
    "You sent a request to join {circle}" : "{circle} zirkuluan sartzeko eskaera bidali duzu",
    "{member} sent a request to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera egin du",
    "You are the new owner of {circle}" : "{circle} zirkuluaren jabe zara orain",
    "{member} is the new owner of {circle}" : "{member} kidea {circle} zirkuluaren jabe da orain",
    "Shared to Circles" : "Zirkuluetara partekatua",
    "Single" : "Bakana",
    "Personal" : "Pertsonala",
    "System" : "Sistema",
    "Visible" : "Ikusgai",
    "Open" : "Ireki",
    "Invite" : "Gonbidatu",
    "Friends" : "Lagunak",
    "Password protected" : "Pasahitz bidez babestuta",
    "No Owner" : "Jaberik ez",
    "Hidden" : "Ezkutuan",
    "Backend" : "Atzealdea",
    "Local" : "Lokala",
    "Root" : "Erroa",
    "Federated" : "Federatua",
    "Mount point" : "Muntatze-puntua",
    "Nextcloud Account" : "Nextcloud kontua",
    "Nextcloud Group" : "Nextcloud taldea",
    "Email address" : "Helbide elektronikoa",
    "Contact" : "Kontaktua",
    "Circle" : "Zirkulua",
    "Nextcloud App" : "Nextcloud aplikazioa",
    "Member" : "Kidea",
    "Moderator" : "Moderatzailea",
    "Admin" : "Administratzailea",
    "Owner" : "Jabea",
    "%s shared »%s« with you." : "%s(e)k »%s« partekatu du zurekin.",
    "%s shared »%s« with \"%s\"." : "%s(e)k »%s« partekatu du  \"%s\"-(r)ekin.",
    "%s on %s" : "%s hemen: %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s(e)k »%2$s« partekatu du zurekin.\nBertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s-k »%2$s« partekatu du zurekin. Bertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
    "Password to access »%1$s« shared to you by %2$s" : "»%1$s« atzitzeko pasahitza partekatu du zurekin %2$s(e)k",
    "Password to access »%s«" : "»%s« atzitzeko pasahitza",
    "It is protected with the following password:" : "Honako pasahitz honekin babestuta dago:",
    "%1$s via %2$s" : "%2$s bidez, %1$s",
    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko",
    "Open »%s«" : "Ireki »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s-k fitxategi batzuk partekatu ditu zurekin.\nHaietara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s-k fitxategi batzuk partekatu ditu zurekin. Haietara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
    "Password to access files shared to you by %1$s" : "Fitxategiak atzitzeko pasahitza partekatu du zurekin »%1$s«(e)k",
    "Password to access files" : "Fitxategiak atzitzeko pasahitza",
    "%s shared multiple files with \"%s\"." : "%s(e)k fitxategi batzuk partekatu ditu  \"%s\"-(r)ekin.",
    "%s shared multiple files with you." : "%s(e)k fitxategi batzuk partekatu ditu zurekin.",
    "Boot up" : "Abiarazi",
    "Nextcloud Initialization" : "Nextcloud hastapena",
    "Circles App Initialization" : "Zirkuluak aplikazioaren hastapena",
    "Fresh installation status" : "Instalazio berriaren egoera",
    "Building Local Database" : "Datu-base lokala eraikitzen",
    "Testing Basic Circle Creation" : "Oinarrizko zirkulu sorrera probatzen",
    "Adding local users and moderators" : "Erabiltzaile eta moderatzaile lokalak gehitzen",
    "This feature is not available for personal circles" : "Ezaugarri hau ez da existitzen zirkulu pertsonaletarako",
    "This member is not a moderator" : "Kide hau ez da moderatzailea",
    "Insufficient privileges" : "Baimen gutxiegi",
    "This member does not exist" : "Kide hau ez da existitzen",
    "Level cannot be changed for this type of member" : "Ezin da mota honetako kideen maila aldatu",
    "You are already a member of this circle" : "Zirkulu honetako kide zara dagoeneko",
    "You have been blocked from this circle" : "Zirkulu honetan blokeatu egin zaituzte",
    "The account is already a member of this circle" : "Kontu hau zirkulu honetako kidea da dagoeneko",
    "The account has already been invited into this circle" : "Kontua zirkulu honetara gonbidatua izan da dagoeneko",
    "You are now a member of the Circle \"%2$s\"" : "«%2$s» zirkuluaren kide zara orain",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s(e)k «%2$s» zirkulura gonbidatu zaitu",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s(e)k «%2$s» zirkuluaren kide izateko eskaera bidali du",
    "Accept" : "Onartu",
    "Refuse" : "Ukatu",
    "Leave the circle" : "Utzi zirkulua",
    "%s" : "%s",
    "%s owned by %s" : "%s jabea: %s",
    "%s shared a file with \"%s\"." : "%s fitxategi bat partekatu du \"%s\"(r)ekin.",
    "%s shared a file with you." : "%s zurekin fitxategi bat partekatu du.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s(e)k eduki batzuk partekatu ditu zurekin.\nBertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s(e)k eduki batzuk partekatu ditu zurekin. Bertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
    "Password to access content shared with you by %1$s" : "%1$s-k zurekin partekatutako edukiera atzitzeko pasahitza",
    "Password to access content" : "Edukia atzitzeko pasahitza",
    "Bring cloud-users closer together." : "Elkartu gehiago hodei erabiltzaileak.",
    "No files in here" : "Ez dago fitxategirik hemen",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan ",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatua",
    "Circles" : "Zirkuluak",
    "Circles' files" : "Zirkuluen fitxategiak",
    "Select circles to filter by" : "Hautatu zirkuluak nola iragazi",
    "No circles found" : "Ez da zirkulurik aurkitu",
    "Please select circles to filter by" : "Hautatu zirkuluak nola iragazi",
    "No files found for the selected circles" : "Ez da fitxategirik aurkitu hautatutako zirkuluetarako",
    "You created the circle {circle}" : "{circle} zirkulua zuk sortu duzu",
    "{author} created the circle {circle}" : "{author}(e)k {circle} zirkulua sortu du",
    "You linked {group} to {circle}" : "{group} taldea {circle} zirkuluarekin lotu duzu",
    "{group} has been linked to {circle} by {author}" : "{group} taldea {circle} zirkuluarekin lotu du {author}(e)k",
    "You unlinked {group} from {circle}" : "{group} taldea {circle} zirkulutik atera duzu",
    "{group} has been unlinked from {circle} by {author}" : "{group} taldea {circle} zirkulutik atera du {author}(e)k",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Lotuta dagoen {group} taldearen maila aldatu duzu {circle} zirkuluan %1$s-ra",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author}(e)k lotuta dagoen {group} taldearen maila aldatu du {circle} zirkuluan %1$s-ra",
    "You sent a request to link {circle} with {remote}" : "Eskaera bidali duzu {circle} lotzeko [remote]rekin",
    "{author} sent a request to link {circle} with {remote}" : "{author}(e)k eskaera bidali du {circle} lotzeko [remote]rekin",
    "{remote} requested a link with {circle}" : "{remote}(e)k eskaera egin du {circle} zirkuluarekin lotzeko ",
    "The request to link {circle} with {remote} has been rejected" : "{circle} eta {remote} lotzeko eskaera baztertua izan da ",
    "The request to link {remote} with {circle} has been canceled remotely" : "{circle} eta {remote} lotzeko eskaera urrunetik bertan behera utzia izan da ",
    "The request to link {circle} with {remote} has been accepted" : "{circle} eta {remote} lotzeko eskaera onartua izan da ",
    "You dismissed the request to link {remote} with {circle}" : "{circle} eta [remote] lotzeko eskaera baztertu duzu",
    "{author} dismissed the request to link {remote} with {circle}" : "{author}(e)k baztertu egin du {circle} eta [remote] lotzeko eskaera",
    "You canceled the request to link {circle} with {remote}" : "{circle} eta [remote] lotzeko eskaera bertan behera utzi duzu",
    "{author} canceled the request to link {circle} with {remote}" : "{author}(e)k bertan behera utzi du {circle} eta [remote] lotzeko eskaera",
    "You accepted the request to link {remote} with {circle}" : "{circle} eta [remote] lotzeko eskaera onartu duzu",
    "{author} accepted the request to link {remote} with {circle}" : "{author}(e)k onartu egin du {circle} eta [remote] lotzeko eskaera",
    "A link between {circle} and {remote} is now up and running" : "{circle} eta {remote}(r)en arteko lotura martxan da eta badabil ",
    "The link between {circle} and {remote} has been shutdown remotely" : "{circle} eta {remote}(r)en arteko lotura urrunetik itzali da ",
    "You closed the link between {circle} and {remote}" : "{circle} eta [remote](r)en arteko lotura eten egin duzu",
    "{author} closed the link between {circle} and {remote}" : "{author}(e)k eten egin du {circle} eta [remote](r)en arteko lotura",
    "{member} cancelled his request to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera bertan behera utzi du",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Kide zaren <strong>zirkuluetako</strong> gertaeretan",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Moderatzen ari zaren <strong>zirkulu</strong> bateko edozein gertaera garrantzitsu",
    "On global events happening in any <strong>Circle</strong>" : "<strong>Zirkulu</strong> batean gertatzen diren gertaera orokorretan",
    "Join Request" : "Sartzeko eskaera",
    "Password Protected" : "Pasahitzez babestua",
    "Circle Invite" : "Zirkulu gonbidapena",
    "Email Address" : "Helbide elektronikoa",
    "Initialisation Nextcloud" : "Hasieratze Nextcloud",
    "Initialisation Circles App" : "Hasieratze zirkulu aplikazioa",
    "Circle not found" : "Ez da zirkulua aurkitu",
    "Circle not found " : "Ez da zirkulua aurkitu",
    "This account is already a member of the circle" : "Kontu hau zirkuluko kidea da dagoeneko",
    "Federated link not found" : "Ez da esteka federatua aurkitu",
    "The circle is not federated" : "Zirkulua ez dago federatuta",
    "You cannot join this circle" : "Ezin zara zirkulu honetan sartu",
    "This member is the owner of the circle" : "Kide hau da zirkuluaren jabea",
    "%s (Circle owned by %s)" : "%s (%s-(r)en jabetzako zirkulua)",
    "Personal Circle" : "Zirkulu pertsonala",
    "You need a specify a type of circle" : "Zirkulu mota zehaztu behar duzu",
    "A circle with that name exists" : "Badago izen bereko beste zirkulu bat ",
    "This member is not the owner of the circle" : "Kide hau ez da zirkuluaren jabea",
    "This member is not an admin of the circle" : "Kide hau ez da zirkuluaren administratzailea",
    "Group contains too many members" : "Taldeak kide gehiegi ditu",
    "This group does not exist" : "Talde hau ez da existitzen",
    "This group is already linked to the circle" : "Talde hau zirkuluarekin loturik dago dagoeneko",
    "You cannot edit level in a personal circle" : "Ezin duzu maila aldatu zirkulu pertsonaletan",
    "Group cannot be set as owner of a circle" : "Taldeak ezin dira zirkulu jabe bihurtu",
    "now" : "orain",
    "This account does not exist" : "Kontu hau ez da existitzen",
    "Email format is not valid" : "Posta-helbidearen formatua ez da baliozkoa",
    "This contact is not available" : "Kontaktu hori ez dago erabilgarri",
    "You have no permission to create a new circle" : "Ez duzu zirkulu berri bat sortzeko baimenik",
    "This item is already shared with this circle" : "Elementu hau dagoeneko partekatu da zirkulu honekin",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Circles jendeak erabiltzaile/lankide/lagun taldeak sortzen ahalbidetzen die.\nPertsona talde (edo \"zirkulu\") hauek beste aplikazio batzuetan erabili daitezke partekatzeko xedearekin. "
},
"nplurals=2; plural=(n != 1);");
